// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0

#pragma once

#include <QCoreApplication>

namespace Todo {

struct Tr
{
    Q_DECLARE_TR_FUNCTIONS(QtC::Todo)
};

} // namespace Todo
